##  Structure Your Transformation Program
Now, bring in more structure into your transformation by creating a hierarchy of your Initiatives, Programs, and Projects. Here is an example of what it might resemble:
  * Level 1 - Initiative for one scenario “New Implementation”
  * Level 2 - Workstream, e.g., HR
  * Level 3 - Smaller, broken-down Initiatives. You can also create multiple scenarios representing different approaches and implementations (e.g., various application implementation or replacement scenarios, marked as “Option A” and “Option B”).


We recommend selecting an approach that best suits your organizational needs.
![Hierarchy visualized in the Relation Explorer](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2752d80b7a441014875a9bef8cf03b92_LowRes.png)
Hierarchy visualized in the Relation Explorer
![Initiative Fact Sheet showing the hierarchy structure in the title and Relation Explorer sections](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d43eb7a4410149bcddb8ba377958e_LowRes.png)
Initiative Fact Sheet showing the hierarchy structure in the title and Relation Explorer sections
![Initiative Fact Sheet showing the hierarchy structure in the Dependencies section](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2743c51b7a441014a14a91886d81c174_LowRes.png)
Initiative Fact Sheet showing the hierarchy structure in the Dependencies section
An alternative approach could be:
  * Level 1 - Your overall transformation program, which will be your umbrella project, in the example below it is ‘ERP Transformation’
  * Level 2 - Children projects based on your transformation strategy; in the example below, it is divided into SAP Activate phases.
  * You could now add a level 3, which involves smaller, broken-down projects in multiple scenarios representing different approaches and implementations (e.g., various application implementation scenarios, etc.).


We recommend selecting an approach that best suits your organizational needs.
![Roadmap Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757df0c7a441014a5d3e4bb3344b1ca_LowRes.png)
Roadmap Report
Having this data will allow you to understand and visualize the transformation from the dimensions that are most important to your organization, For instance:
  * What are the major dependencies between different parts of the transformation?
  * When will each region or business unit be impacted by the ERP rollout?
  * Is the rollout staggered, or is it a 'big bang'?


Each initiative with its Milestones can represent a scenario that you can 'play around' with to facilitate informed decision-making for the key stakeholders of the transformation program.
